@@ -56,11 +56,11 @@ write.list.Excel <- function(x, fName) {
      if (require(RODBC)==FALSE) {
         stop("This function requires package RODBC")
      }
-     fp <- RODBC:::full.path(fName)
-     con <- paste("Driver={Microsoft Excel Driver (*.xls)};DriverId=790;Dbq=", fp, ";DefaultDir=", dirname(fp), ";", sep = "")
-     con = paste(con, "ReadOnly=False", sep = ";")
-     channel <- odbcDriverConnect(con, tabQuote = c("[", "]"))
-#     channel <- odbcConnectExcel(fName, readOnly=FALSE)
+#     fp <- RODBC:::full.path(fName)
+#     con <- paste("Driver={Microsoft Excel Driver (*.xls)};DriverId=790;Dbq=", fp, ";DefaultDir=", dirname(fp), ";", sep = "")
+#     con = paste(con, "ReadOnly=False", sep = ";")
+#     channel <- odbcDriverConnect(con, tabQuote = c("[", "]"))
+     channel <- odbcConnectExcel(fName, readOnly=FALSE)
      if (channel == -1)
         stop(paste("Could not open file ", fName, "for writing. Is it already open?", sep=""))
      nms <- names(x)
